@@ -662,7 +662,7 @@ class PyKCS11Lib(object):
         for x in range(len(mechanismList)):
             mechanism = mechanismList[x]
             if mechanism >= CKM_VENDOR_DEFINED:
-                k = 'CKR_VENDOR_DEFINED_%X' % (mechanism - CKM_VENDOR_DEFINED)
+                k = 'CKM_VENDOR_DEFINED_0x%X' % (mechanism - CKM_VENDOR_DEFINED)
                 CKM[k] = mechanism
                 CKM[mechanism] = k
             m.append(CKM[mechanism])
@@ -1289,7 +1289,8 @@ class Session(object):
         :param type: PKCS#11 type like `CKA_ALWAYS_SENSITIVE`
         :rtype: bool
         """
-        if type in (CKA_ALWAYS_SENSITIVE,
+        if type in (CKA_ALWAYS_AUTHENTICATE,
+                    CKA_ALWAYS_SENSITIVE,
                     CKA_DECRYPT,
                     CKA_DERIVE,
                     CKA_ENCRYPT,
